@@ -13,7 +13,7 @@ setMethod(
               if (length(object@params)>0) {
                 params <- object@params
               } else {
-                stop("pfilter error: 'params' must be supplied",call.=FALSE)
+                stop("pfilter error: ",sQuote("params")," must be supplied",call.=FALSE)
               }
             }
             if (missing(Np))
@@ -33,7 +33,7 @@ setMethod(
             npars <- nrow(params)
             paramnames <- rownames(params)
             if (is.null(paramnames))
-              stop("pfilter error: 'params' must have rownames",call.=FALSE)
+              stop("pfilter error: ",sQuote("params")," must have rownames",call.=FALSE)
 
             xstart <- init.state(object,params=params)
             statenames <- rownames(xstart)
@@ -43,9 +43,9 @@ setMethod(
             if (random.walk) {
               rw.names <- names(.rw.sd)
               if (is.null(rw.names)||!is.numeric(.rw.sd))
-                stop("pfilter error: '.rw.sd' must be a named vector",call.=FALSE)
+                stop("pfilter error: ",sQuote(".rw.sd")," must be a named vector",call.=FALSE)
               if (any(!(rw.names%in%paramnames)))
-                stop("pfilter error: the rownames of 'params' must include all of the names of '.rw.sd'",call.=FALSE)
+                stop("pfilter error: the rownames of ",sQuote("params")," must include all of the names of ",sQuote(".rw.sd"),"",call.=FALSE)
               sigma <- .rw.sd
             }
             
@@ -121,16 +121,16 @@ setMethod(
                 problem.indices <- unique(which(!is.finite(x),arr.ind=TRUE)[,1])
                 if (length(problem.indices)>0) {
                   stop(
-                       "pfilter error: non-finite state variables ",
-                       paste(rownames(x)[problem.indices],collapse=','),
+                       "pfilter error: non-finite state variable(s): ",
+                       paste(rownames(x)[problem.indices],collapse=', '),
                        call.=FALSE
                        )
                 }
                 problem.indices <- unique(which(!is.finite(params),arr.ind=TRUE)[,1])
                 if (length(problem.indices)>0) {
                   stop(
-                       "pfilter error: non-finite parameters ",
-                       paste(rownames(params)[problem.indices],collapse=','),
+                       "pfilter error: non-finite parameter(s): ",
+                       paste(rownames(params)[problem.indices],collapse=', '),
                        call.=FALSE
                        )
                 }
