@@ -7,39 +7,39 @@ pomp <- function (data, times, t0, ..., rprocess, dprocess,
   ## check the data
   if (is.data.frame(data)) {
     if (!is.character(times) || length(times)!=1 || !(times%in%names(data)))
-      stop("pomp error: 'times' must be the name of a column of 'data'")
+      stop("pomp error: ",sQuote("times")," must be the name of a column of ",sQuote("data"))
     tmnm <- times
     times <- data[[tmnm]]
     data <- do.call(rbind,lapply(data[!(names(data)%in%tmnm)],as.numeric))
   }
   if (!is.numeric(data))
-    stop("pomp error: 'data' must be numeric")
+    stop("pomp error: ",sQuote("data")," must be numeric")
   if (!is.array(data))
     data <- array(data,dim=c(1,length(data)),dimnames=list("data",NULL))
   storage.mode(data) <- 'double'
   
   ## check times
   if (!is.numeric(times) || !all(diff(times)>0))
-    stop("pomp error: 'times' must be an increasing numeric vector")
+    stop("pomp error: ",sQuote("times")," must be an increasing numeric vector")
   if (length(times)!=ncol(data))
-    stop("pomp error: the length of 'times' does not equal the number of columns in 'data'")
+    stop("pomp error: the length of ",sQuote("times")," does not equal the number of columns in ",sQuote("data"))
   storage.mode(times) <- 'double'
   
   ## check t0
   if (!is.numeric(t0) || length(t0) > 1)
-    stop("pomp error: the zero-time 't0' must be a single number")
+    stop("pomp error: the zero-time ",sQuote("t0")," must be a single number")
   if (t0 > times[1])
-    stop("pomp error: the zero-time 't0' must occur no later than the first observation")
+    stop("pomp error: the zero-time ",sQuote("t0")," must occur no later than the first observation")
   storage.mode(t0) <- 'double'
   
   if (missing(rprocess))
-    rprocess <- function(xstart,times,params,...)stop("'rprocess' not specified")
+    rprocess <- function(xstart,times,params,...)stop(sQuote("rprocess")," not specified")
   if (missing(dprocess))
-    dprocess <- function(x,times,params,log=FALSE,...)stop("'dprocess' not specified")
+    dprocess <- function(x,times,params,log=FALSE,...)stop(sQuote("dprocess")," not specified")
 
   if (!missing(measurement.model)) {
     if (!(missing(dmeasure)&&missing(rmeasure))) {
-      warning("specifying 'measurement.model' overrides specification of 'rmeasure' and 'dmeasure'")
+      warning("specifying ",sQuote("measurement.model")," overrides specification of ",sQuote("rmeasure")," and ",sQuote("dmeasure"))
     }
     mm <- measform2pomp(measurement.model)
     rmeasure <- mm$rmeasure
@@ -47,17 +47,17 @@ pomp <- function (data, times, t0, ..., rprocess, dprocess,
   }
   
   if (missing(rmeasure))
-    rmeasure <- function(x,t,params,covars,...)stop("'rmeasure' not specified")
+    rmeasure <- function(x,t,params,covars,...)stop(sQuote("rmeasure")," not specified")
   if (missing(dmeasure))
-    dmeasure <- function(y,x,t,params,log=FALSE,covars,...)stop("'dmeasure' not specified")
+    dmeasure <- function(y,x,t,params,log=FALSE,covars,...)stop(sQuote("dmeasure")," not specified")
   if (missing(skeleton))
-    skeleton <- function(x,t,params,covars,...)stop("'skeleton' not specified")
+    skeleton <- function(x,t,params,covars,...)stop(sQuote("skeleton")," not specified")
 
   if (missing(initializer)) {
     initializer <- function (params, t0, ...) {
       ivpnames <- grep("\\.0$",names(params),val=TRUE)
       if (length(ivpnames)<1)
-        stop("default initializer error: no parameter names ending in '.0' found: see 'pomp' documentation")
+        stop("default initializer error: no parameter names ending in ",sQuote(".0")," found: see ",sQuote("pomp")," documentation")
       x <- params[ivpnames]
       names(x) <- sub("\\.0$","",ivpnames)
       x
@@ -67,13 +67,13 @@ pomp <- function (data, times, t0, ..., rprocess, dprocess,
   if (missing(PACKAGE)) PACKAGE <- character(0)
   
   if (!is.function(rprocess))
-    stop("pomp error: 'rprocess' must be a function")
+    stop("pomp error: ",sQuote("rprocess")," must be a function")
   if (!is.function(dprocess))
-    stop("pomp error: 'dprocess' must be a function")
+    stop("pomp error: ",sQuote("dprocess")," must be a function")
 
   if (is.function(rmeasure)) {
     if (!all(c('x','t','params','...')%in%names(formals(rmeasure))))
-      stop("'rmeasure' must be a function of prototype 'rmeasure(x,t,params,...)'")
+      stop(sQuote("rmeasure")," must be a function of prototype ",sQuote("rmeasure(x,t,params,...)"))
     rmeasure <- new(
                     "pomp.fun",
                     R.fun=rmeasure,
@@ -88,12 +88,12 @@ pomp <- function (data, times, t0, ..., rprocess, dprocess,
                     use=as.integer(2)
                     )
   } else {
-    stop("'rmeasure' must be either a function or the name of a compiled routine")
+    stop(sQuote("rmeasure")," must be either a function or the name of a compiled routine")
   }
   
   if (is.function(dmeasure)) {
     if (!all(c('y','x','t','params','log','...')%in%names(formals(dmeasure))))
-      stop("'dmeasure' must be a function of prototype 'dmeasure(y,x,t,params,log,...)'")
+      stop(sQuote("dmeasure")," must be a function of prototype ",sQuote("dmeasure(y,x,t,params,log,...)"))
     dmeasure <- new(
                     "pomp.fun",
                     R.fun=dmeasure,
@@ -108,12 +108,12 @@ pomp <- function (data, times, t0, ..., rprocess, dprocess,
                     use=as.integer(2)
                     )
   } else {
-    stop("'dmeasure' must be either a function or the name of a compiled routine")
+    stop(sQuote("dmeasure")," must be either a function or the name of a compiled routine")
   }
   
   if (is.function(skeleton)) {
     if (!all(c('x','t','params','...')%in%names(formals(skeleton))))
-      stop("'skeleton' must be a function of prototype 'skeleton(x,t,params,...)'")
+      stop(sQuote("skeleton")," must be a function of prototype ",sQuote("skeleton(x,t,params,...)"))
     skeleton <- new(
                     "pomp.fun",
                     R.fun=skeleton,
@@ -128,18 +128,18 @@ pomp <- function (data, times, t0, ..., rprocess, dprocess,
                     use=as.integer(2)
                     )
   } else {
-    stop("'skeleton' must be either a function or the name of a compiled routine")
+    stop(sQuote("skeleton")," must be either a function or the name of a compiled routine")
   }
   
   if (!is.function(initializer))
-    stop("pomp error: 'initializer' must be a function")
+    stop("pomp error: ",sQuote("initializer")," must be a function")
   
   if (!all(c('xstart','times','params','...')%in%names(formals(rprocess))))
-    stop("pomp error: 'rprocess' must be a function of prototype 'rprocess(xstart,times,params,...)'")
+    stop("pomp error: ",sQuote("rprocess")," must be a function of prototype ",sQuote("rprocess(xstart,times,params,...)"))
   if (!all(c('x','times','params','log','...')%in%names(formals(dprocess))))
-    stop("pomp error: 'dprocess' must be a function of prototype 'dprocess(x,times,params,log,...)'")
+    stop("pomp error: ",sQuote("dprocess")," must be a function of prototype ",sQuote("dprocess(x,times,params,log,...)"))
   if (!all(c('params','t0','...')%in%names(formals(initializer))))
-    stop("pomp error: 'initializer' must be a function of prototype 'initializer(params,t0,...)'")
+    stop("pomp error: ",sQuote("initializer")," must be a function of prototype ",sQuote("initializer(params,t0,...)"))
   
   if (missing(statenames)) statenames <- character(0)
   if (missing(paramnames)) paramnames <- character(0)
@@ -150,7 +150,7 @@ pomp <- function (data, times, t0, ..., rprocess, dprocess,
     tcovar <- numeric(0)
     covarnames <- character(0)
   } else if (missing(tcovar)) {
-    stop("if 'covar' is supplied, 'tcovar' must be supplied also")
+    stop("if ",sQuote("covar")," is supplied, ",sQuote("tcovar")," must be supplied also")
   } else if (is.data.frame(covar)) {
     if (
         (
@@ -165,7 +165,7 @@ pomp <- function (data, times, t0, ..., rprocess, dprocess,
          !(tcovar%in%names(covar))
          )
         ) {
-      stop("if 'covar' is a data frame, 'tcovar' should indicate the time variable")
+      stop("if ",sQuote("covar")," is a data frame, ",sQuote("tcovar")," should indicate the time variable")
     } else {
       tcovar <- covar[[tcovar]]
       covar <- as.matrix(covar[-tcovar])
@@ -175,12 +175,12 @@ pomp <- function (data, times, t0, ..., rprocess, dprocess,
   }
   
   if (length(tcovar)!=nrow(covar)) {
-    stop("the length of 'tcovar' should match the number of rows of 'covar'")
+    stop("the length of ",sQuote("tcovar")," should match the number of rows of ",sQuote("covar"))
   } else if (!all(covarnames%in%colnames(covar))) {
     missing <- covarnames[!(covarnames%in%colnames(covar))]
-    stop("covariate(s) ",paste(missing,collapse=",")," are not found among the columns of 'covar'")
+    stop("covariate(s) ",paste(missing,collapse=",")," are not found among the columns of ",sQuote("covar"))
   } else if (!is.numeric(tcovar)) {
-    stop("'tcovar' must either be a numeric vector or must name a numeric vector in the data frame 'covar'")
+    stop(sQuote("tcovar")," must either be a numeric vector or must name a numeric vector in the data frame ",sQuote("covar"))
   }
 
   if (nrow(covar)>0) {
@@ -188,17 +188,17 @@ pomp <- function (data, times, t0, ..., rprocess, dprocess,
         (skeleton@use==1)
         &&!("covars"%in%names(formals(skeleton@R.fun)))
         )
-      warning("a covariate table has been given, yet the 'skeleton' function does not have 'covars' as a formal argument")
+      warning("a covariate table has been given, yet the ",sQuote("skeleton")," function does not have ",sQuote("covars")," as a formal argument")
     if (
         (rmeasure@use==1)
         &&!("covars"%in%names(formals(rmeasure@R.fun)))
         )
-      warning("a covariate table has been given, yet the 'rmeasure' function does not have 'covars' as a formal argument")
+      warning("a covariate table has been given, yet the ",sQuote("rmeasure")," function does not have ",sQuote("covars")," as a formal argument")
     if (
         (dmeasure@use==1)
         &&!("covars"%in%names(formals(dmeasure@R.fun)))
         )
-      warning("a covariate table has been given, yet the 'dmeasure' function does not have 'covars' as a formal argument")
+      warning("a covariate table has been given, yet the ",sQuote("dmeasure")," function does not have ",sQuote("covars")," as a formal argument")
   }
 
   new(
@@ -230,7 +230,7 @@ measform2pomp <- function (formulae) {
     stop("you must provide at least one formula")
   for (k in 1:nobs) {
     if (!inherits(formulae[[k]],"formula"))
-      stop("'measurement.model' takes formulae as arguments")
+      stop(sQuote("measurement.model")," takes formulae as arguments")
   }
   obsnames <- unlist(lapply(formulae,function(x)x[[2]]))
   distrib <- lapply(formulae,function(x)as.character(x[[3]][[1]]))
