@@ -1,15 +1,5 @@
 require(pomp)
 
-modelfile <- system.file("examples/sir.c",package="pomp")
-includedir <- system.file("include",package="pomp")
-lib <- system.file("libs/pomp.so",package="pomp")
-
-## compile the model into shared-object library
-system(paste("cp",modelfile,"."))
-system(paste("cp ",includedir,"/euler.h .",sep=""))
-system(paste("cp ",includedir,"/lookup_table.h .",sep=""))
-system(paste("R CMD SHLIB -o sir.so sir.c",lib))
-
 ## basis functions for the seasonality
 tbasis <- seq(0,25,by=1/52)
 basis <- periodic.bspline.basis(tbasis,nbasis=3)
@@ -27,18 +17,13 @@ params <- c(
 
 ## set up the pomp object
 po <- pomp(
-           times=seq(1/52,4,by=1/52),
+           times=1/52*seq.int(length=4*52),
            data=rbind(measles=numeric(52*4)),
            t0=0,
            tcovar=tbasis,
            covar=basis,
            delta.t=1/52/20,
-           statenames=c("S","I","R","cases","W","B","dW"),
-           paramnames=c("gamma","mu","iota","beta1","beta.sd","pop"),
-           covarnames=c("seas1"),
            zeronames=c("cases"),
-           measurement.model=measles~binom(size=cases,prob=exp(rho)),
-           rprocess=euler.simulate,
            step.fun=function(t,x,params,covars,delta.t,...) {
              params <- exp(params)
              with(
@@ -55,18 +40,22 @@ po <- pomp(
                                reulermultinom(n=1,size=R,rate=c(mu),dt=delta.t)
                                )
                     c(
-                      S+trans[1]-trans[2]-trans[3],
-                      I+trans[2]-trans[4]-trans[5],
-                      R+trans[4]-trans[6],
-                      cases+trans[4],
-                      if (beta.sd>0) W+(dW-delta.t)/beta.sd else W,
-                      trans,
-                      dW
+                      S=S+trans[1]-trans[2]-trans[3],
+                      I=I+trans[2]-trans[4]-trans[5],
+                      R=R+trans[4]-trans[6],
+                      cases=cases+trans[4],
+                      W=if (beta.sd>0) W+(dW-delta.t)/beta.sd else W,
+                      B=trans[1],
+                      SI=trans[2],
+                      SD=trans[3],
+                      IR=trans[4],
+                      ID=trans[5],
+                      RD=trans[6],
+                      dW=dW
                       )
                   }
                   )
            },
-           dprocess=euler.density,
            dens.fun=function(t1,t2,params,x1,x2,covars,...) {
              params <- exp(params)
              with(
@@ -112,50 +101,9 @@ po <- pomp(
                   }
                   )
            },
-           initializer=function(params,t0,...){
-             p <- exp(params)
-             with(
-                  as.list(p),
-                  {
-                    fracs <- c(S.0,I.0,R.0)
-                    x0 <- c(
-                            round(pop*fracs/sum(fracs)), # make sure the three compartments sum to 'pop' initially
-                            rep(0,9)	# zeros for 'cases', 'W', and the transition numbers
-                            )
-                    names(x0) <- c("S","I","R","cases","W","B","SI","SD","IR","ID","RD","dW")
-                    x0
-                  }
-                  )
-           }
-           )
-
-set.seed(3049953)
-## simulate from the model
-tic <- Sys.time()
-x <- simulate(po,params=log(params),nsim=3)
-toc <- Sys.time()
-print(toc-tic)
-
-# alternatively, one can define the computationally intensive bits using native routines:
-## the C codes "sir_euler_simulator" and "sir_euler_density" are included in the "examples" directory (file "sir.c")
-po <- pomp(
-           times=seq(1/52,4,by=1/52),
-           data=rbind(measles=numeric(52*4)),
-           t0=0,
-           tcovar=tbasis,
-           covar=basis,
-           delta.t=1/52/20,
-           statenames=c("S","I","R","cases","W","B","dW"),
-           paramnames=c("gamma","mu","iota","beta1","beta.sd","pop"),
-           covarnames=c("seas1"),
-           zeronames=c("cases"),
-           measurement.model=measles~binom(size=cases,prob=exp(rho)),
            rprocess=euler.simulate,
-           step.fun="sir_euler_simulator",
            dprocess=euler.density,
-           dens.fun="sir_euler_density",
-           skeleton="sir_ODE",
-           PACKAGE="pomp",
+           measurement.model=measles~binom(size=cases,prob=exp(rho)),
            initializer=function(params,t0,...){
              p <- exp(params)
              with(
@@ -173,13 +121,63 @@ po <- pomp(
            }
            )
 
-dyn.load("sir.so")                    # load the shared-object library
+## alternatively, one can define the computationally intensive bits using native routines:
+## the C codes "sir_euler_simulator" and "sir_euler_density" are included in the "examples" directory (file "sir.c")
 
-## simulate from the model
-tic <- Sys.time()
-x <- simulate(po,params=log(params),nsim=3)
-toc <- Sys.time()
-print(toc-tic)
-plot(x[[1]])
+if (.Platform$OS.type=='unix') {
 
-dyn.unload("sir.so")
+  modelfile <- system.file("examples/sir.c",package="pomp")
+  includedir <- system.file("include",package="pomp")
+  lib <- system.file("libs/pomp.so",package="pomp")
+
+  ## compile the model into a shared-object library
+  system(paste("cp",modelfile,"."))
+  system(paste("cp ",includedir,"/pomp.h .",sep=""))
+  system(paste("R CMD SHLIB -o ./sir_example.so sir.c",lib))
+
+  po <- pomp(
+             times=seq(1/52,4,by=1/52),
+             data=rbind(measles=numeric(52*4)),
+             t0=0,
+             tcovar=tbasis,
+             covar=basis,
+             delta.t=1/52/20,
+             statenames=c("S","I","R","cases","W","B","dW"),
+             paramnames=c("gamma","mu","iota","beta1","beta.sd","pop"),
+             covarnames=c("seas1"),
+             zeronames=c("cases"),
+             step.fun="sir_euler_simulator",
+             rprocess=euler.simulate,
+             dens.fun="sir_euler_density",
+             dprocess=euler.density,
+             skeleton="sir_ODE",
+             PACKAGE="sir_example", ## name of the shared-object library
+             measurement.model=measles~binom(size=cases,prob=exp(rho)),
+             initializer=function(params,t0,...){
+               p <- exp(params)
+               with(
+                    as.list(p),
+                    {
+                      fracs <- c(S.0,I.0,R.0)
+                      x0 <- c(
+                              round(pop*fracs/sum(fracs)), # make sure the three compartments sum to 'pop' initially
+                              rep(0,9)	# zeros for 'cases', 'W', and the transition numbers
+                              )
+                      names(x0) <- c("S","I","R","cases","W","B","SI","SD","IR","ID","RD","dW")
+                      x0
+                    }
+                    )
+             }
+             )
+
+  dyn.load("sir_example.so") ## load the shared-object library
+
+  ## simulate from the model
+  tic <- Sys.time()
+  x <- simulate(po,params=log(params),nsim=3)
+  toc <- Sys.time()
+  print(toc-tic)
+
+  dyn.unload("sir_example.so")
+
+}
